@@ -14,30 +14,29 @@
 # limitations under the License.
 #
 
-"""
-This module contains file monitoring class that can be used to check files
+"""This module contains file monitoring class that can be used to check files
 change periodically and call callback function to handle properly when
-detecting files change.
-"""
-
+detecting files change."""
 import logging
 import os.path as op
 import threading
 import time
 import traceback
+from typing import Callable, List
 
 __all__ = ["FileChangesChecker", "FileMonitor"]
 
 
 class FileChangesChecker:
-    """Files change checker.
+    """Files change checker."""
 
-    :param callback: Callback function for files change.
-    :param files: Files to be monidtored with full path.
-    :type files: ``list, tuple``
-    """
+    def __init__(self, callback: Callable, files: List):
+        """Initializes FileChangesChecker.
 
-    def __init__(self, callback, files):
+        Arguments:
+            callback: Callback function for files change.
+            files: Files to be monitored with full path.
+        """
         self._callback = callback
         self._files = files
 
@@ -48,14 +47,14 @@ class FileChangesChecker:
             except OSError:
                 logging.debug("Getmtime for %s, failed: %s", k, traceback.format_exc())
 
-    def check_changes(self):
+    def check_changes(self) -> bool:
         """Check files change.
 
         If some files are changed and callback function is not None, call
         callback function to handle files change.
 
-        :returns: True if files changed else False
-        :rtype: ``bool``
+        Returns:
+            True if files changed else False
         """
 
         logging.debug("Checking files=%s", self._files)
@@ -84,19 +83,20 @@ class FileMonitor:
     Monitor files change in a separated thread and call callback
     when there is files change.
 
-    :param callback: Callback for handling files change.
-    :param files: Files to monitor.
-    :type files: ``list, tuple``
-    :param interval: Interval to check files change.
-
-    Usage::
-
-      >>> import splunksolutionlib.file_monitor as fm
+    Examples:
+      >>> import solnlib.file_monitor as fm
       >>> fm = fm.FileMonitor(fm_callback, files_list, 5)
       >>> fm.start()
     """
 
-    def __init__(self, callback, files, interval=1):
+    def __init__(self, callback: Callable, files: List, interval: int = 1):
+        """Initializes FileMonitor.
+
+        Arguments:
+            callback: Callback for handling files change.
+            files: Files to monitor.
+            interval: Interval to check files change.
+        """
         self._checker = FileChangesChecker(callback, files)
         self._thr = threading.Thread(target=self._do_monitor)
         self._thr.daemon = True
